@@ -1,14 +1,13 @@
 
 from enum import Enum
 from typing import Any, List, Optional, Dict
-from dataclasses import dataclass
 
-from pydantic import Field, parse_obj_as, BaseModel
-from deeplabel.basemodel import DeeplabelBase, MixinConfig
+from pydantic import Field
+from deeplabel.basemodel import DeeplabelBase
 import deeplabel.client
 from deeplabel.exceptions import InvalidIdError
 from deeplabel.types.bounding_box import BoundingBox
-from deeplabel.types.polygon import Point, Polygon
+from deeplabel.types.polygon import Polygon
 from deeplabel.label.labels import DetectionLabel
 
 
@@ -27,7 +26,7 @@ class Detection(DeeplabelBase):
 
 
     @classmethod
-    def _from_search_params(
+    def from_search_params(
         cls, params: Dict[str, Any], client: "deeplabel.client.BaseClient"
     ) -> List["Detection"]:
         """Make a get request for detections using the passed params. This
@@ -40,7 +39,7 @@ class Detection(DeeplabelBase):
         detections = resp.json()["data"]["detections"]
         # don't check for empty list in this generic class method. returns empty list if no detections were found
         detections = [cls(**det, client=client) for det in detections]
-        return detections
+        return detections  # type: ignore
 
     @classmethod
     def from_detection_id(cls, detection_id: str, client: "deeplabel.client.BaseClient"):
@@ -56,7 +55,7 @@ class Detection(DeeplabelBase):
         Returns:
             Detection: returns a Detection object or raises InvalidIdError if not found
         """
-        detections = cls._from_search_params({"detectionId": detection_id}, client)
+        detections = cls.from_search_params({"detectionId": detection_id}, client)
         if not len(detections):
             raise InvalidIdError(
                 f"Failed to fetch detections with detectionId  : {detection_id}"
@@ -73,4 +72,4 @@ class Detection(DeeplabelBase):
         Returns:
             List[Detection]: List of detections for the given videoTaskId
         """
-        return cls._from_search_params({"imageId": image_id}, client)
+        return cls.from_search_params({"imageId": image_id}, client)
