@@ -80,6 +80,23 @@ class BoundingBox(BaseModel):
     def to_list(self):
         """Return a list of [xmin,ymin,xmax,ymax] """
         return [self.xmin,self.ymin,self.xmax,self.ymax]
+    
+    def interpolate(self, other:"BoundingBox", factor:float):
+        """Interpolate the current bbox with other bbox with a factor
+
+        Args:
+            other (BoundingBox): other bbox
+            factor (float): factor of current to other bbox. between 0 and 1
+
+        Returns:
+            BoundingBox: Returns interpolated boundingbox
+        """
+        return self.__class__(
+            xmin = factor*self.xmin + (1-factor)*other.xmin,
+            xmax = factor*self.xmax + (1-factor)*other.xmax,
+            ymin = factor*self.ymin + (1-factor)*other.ymin,
+            ymax = factor*self.ymax + (1-factor)*other.ymax,
+        )
 
 
 class BoundingBoxWithNumber(BoundingBox):
